/* Store the previous location to be used when sending referrer on navigations */
var actualReferrer = '';
/**
 * Useful wrapper around document and window objects
 */

export var utils = {
  /**
   * @returns {String} The referrer of the document
   */
  getDocumentReferrer: function getDocumentReferrer() {
    return document.referrer;
  },

  /**
   * @returns {String} The actual location with protocol, domain and pathname
   */
  getActualLocation: function getActualLocation() {
    var _window$location = window.location,
        origin = _window$location.origin,
        pathname = _window$location.pathname;
    return "" + origin + pathname;
  }
};
/**
 * Get the correct page referrer for SPA navigations
 * @returns {String} referrer
 */

export var getPageReferrer = function getPageReferrer() {
  // get the referrer from the previous location if available, fallback to the document
  return actualReferrer || utils.getDocumentReferrer();
};
/**
 * Update page referrer for SPA navigations
 */

export var updatePageReferrer = function updatePageReferrer() {
  // if it's first time we're executing, the actualReferrer is the document.referrer
  if (!actualReferrer) {
    actualReferrer = utils.getDocumentReferrer();
    return;
  } // mutate actualReferrer with what will be the new referrer


  actualReferrer = utils.getActualLocation();
};